==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gods/dialogs_fr.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Je crains que nous allons découvrir quelque chose de terrible.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Je l'ai toujours su : les dieux sont fous.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Dieu est fou et le monde entier est son jouet.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Je pense que tu as raison.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("J'ai bien peur que tu ais raison.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Oui, ça fait un choc.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Qu'allons-nous faire alors ?")


dialogId("lod-v-internovat", "font_big", "We can`t leave it this way. We must incarcerate them.")
dialogStr("Nous ne pouvons pas les laisser continuer comme ça. Nous devons les arrêter.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Que devons nous faire ?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Les mettre en priso... En cellule de détention de la FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Tu as raison. Devons-nous les prendre tous les deux ?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Bien sûr. Si nous en laissons un ici, il pourrait avoir n'importe qu'elle idée folle. Il pourrait commencer à jouer au golf par exemple.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Difficilement avec ce club. Je pense que nous serons contents d'en attraper un. L'autre deviendra alors inoffensif.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Bien. Et lequel ?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Le jaune.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Le bleu.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Ce jaune là.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Ce bleu là.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Laissons le choix au joueur.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Nous devrions laisser le choix au joueur.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Regarde ce club : il lui est arrivé quelque chose de terrible.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Une chose lui a bavé dessus.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Maman avait raison. L'excès de jeu est réellement diabolique.")


dialogId("lod-m-palka", "font_small", "That`s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("C'est vrai. Ce serait plus facile si cette raquette de ping-pong était ailleurs.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("A propos, tu as noté que la véritable balle de golf est dans le coin supérieur gauche, tandis que dans le coin inférieur droit se trouve une balle de cricket ?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Y aurait-il un symbolisme caché ?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Qui sait ?")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Je pense que c'est une balle de ping-pong là haut.")


dialogId("lod-v-rozliseni", "font_big", "It`s hard to say with this screen resolution.")
dialogStr("Difficile à dire avec un écran à cette résolution.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Cette fois, notre but est de faire sortir un de ces dieux.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("touché !")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("touché !")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("touché !")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("touché !")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Coulé !")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Coulé !")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Coulé !")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("J'ai gagné !!!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Je commence !")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Bien !")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Faisons-nous une autre partie ?")


dialogId("b1-nepodvadim", "font_yellow", "I don`t cheat.")
dialogStr("Je ne triche pas.")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("C'est une erreur, probablement...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Coulé !")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Coulé !")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Coulé !")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Hé, hé, hé... J'ai gagné !")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Bien !")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("On en refait une ?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Tu as déjà essayé ça !")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Tu as déjà dit ça !")


dialogId("b2-nemuze", "font_cyan", "It can`t be a miss on this space.")
dialogStr("Il n'y a pas de manqué ici.")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Tu as triché !!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss`!")
dialogStr("J'ai tiré ici - et tu as répondu 'raté' !")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/gods/dialogs_fr.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Je crains que nous allions au devant de quelque chose de terrible.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Je l'ai toujours su : les dieux sont fous.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Dieu est fou et le monde entier est son jouet.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Je pense que tu as raison.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("J'ai bien peur que tu aies raison.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Oui, ça fait un choc.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Qu'allons-nous faire alors ?")


dialogId("lod-v-internovat", "font_big", "We can’t leave it this way. We must incarcerate them.")
dialogStr("Nous ne pouvons pas les laisser continuer comme ça. Nous devons les arrêter.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Que devons nous faire ?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Les mettre en priso... En cellule de détention de la FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Tu as raison. Devons-nous les prendre tous les deux ?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Bien sûr. Si nous en laissons un ici, il pourrait avoir n'importe qu'elle idée folle. Il pourrait commencer à jouer au golf par exemple.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Difficilement avec ce club. Je pense que nous serons contents d'en attraper un. L'autre deviendra alors inoffensif.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Bien. Et lequel ?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Le jaune.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Le bleu.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Ce jaune là.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Ce bleu là.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Laissons le choix au joueur.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Nous devrions laisser le choix au joueur.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Regarde ce club : il lui est arrivé quelque chose de terrible.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Une chose lui a bavé dessus.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Maman avait raison. L'excès de jeu est réellement diabolique.")


dialogId("lod-m-palka", "font_small", "That’s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("C'est vrai. Ce serait plus facile si cette raquette de ping-pong était ailleurs.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("A propos, tu as noté que la véritable balle de golf est dans le coin supérieur gauche, tandis que dans le coin inférieur droit se trouve une balle de cricket ?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Y aurait-il un symbolisme caché ?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Qui sait ?")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Je pense que c'est une balle de ping-pong là haut.")


dialogId("lod-v-rozliseni", "font_big", "It’s hard to say with this screen resolution.")
dialogStr("Difficile à dire avec un écran à cette résolution.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Cette fois, notre but est de faire sortir un de ces dieux.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Raté !")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Touché !")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Touché !")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Touché !")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Touché !")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Coulé !")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Coulé !")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Coulé !")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("J'ai gagné !!!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Je commence !")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Bien !")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Faisons-nous une autre partie ?")


dialogId("b1-nepodvadim", "font_yellow", "I don’t cheat.")
dialogStr("Je ne triche pas.")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("C'était une erreur, probablement...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Raté !")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Touché !")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Coulé !")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Coulé !")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Coulé !")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Hé, hé, hé... J'ai gagné !")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Bien !")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("On en refait une ?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Tu as déjà essayé ça !")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Tu as déjà dit ça !")


dialogId("b2-nemuze", "font_cyan", "It can’t be a miss on this space.")
dialogStr("Il n'y a pas de manqué ici.")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Tu as triché !!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss’!")
dialogStr("J'ai tiré ici - et tu as répondu 'raté' !")
